;; Generated package description from realgud-jdb.el  -*- no-byte-compile: t -*-
(define-package "realgud-jdb" "1.0.0.0.20200722.112030" "Realgud front-end to Java's jdb debugger\"" '((realgud "1.5.0") (load-relative "1.3.1") (emacs "25")) :authors '(("Rocky Bernstein" . "rocky@gnu.org")) :maintainer '("Rocky Bernstein" . "rocky@gnu.org") :url "https://github.com/realgud/realgud-jdb")
